@@ -1,15 +1,13 @@
 /*
  *  zzuf - general purpose fuzzer
- *  Copyright (c) 2006 Sam Hocevar <sam@zoy.org>
- *                All Rights Reserved
  *
- *  $Id$
+ *  Copyright © 2002—2015 Sam Hocevar <sam@hocevar.net>
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
- *  and/or modify it under the terms of the Do What The Fuck You Want
- *  To Public License, Version 2, as published by Sam Hocevar. See
- *  http://sam.zoy.org/wtfpl/COPYING for more details.
+ *  and/or modify it under the terms of the Do What the Fuck You Want
+ *  to Public License, Version 2, as published by the WTFPL Task Force.
+ *  See http://www.wtfpl.net/ for more details.
  */
 
 /*
@@ -33,32 +31,25 @@
 #include <time.h>
 
 #include "timer.h"
+#include "util/mutex.h"
 
-int64_t _zz_time(void)
+int64_t zzuf_time(void)
 {
 #if defined HAVE_GETTIMEOFDAY
     struct timeval tv;
     gettimeofday(&tv, NULL);
     return (int64_t)tv.tv_sec * 1000000 + tv.tv_usec;
 #else
-    static CRITICAL_SECTION cs;
-    static unsigned long int prev;
-    static int64_t tv_base = 0;
-    unsigned long int tv_msec;
+    static zzuf_mutex_t mutex = 0;
+    static unsigned long int prev = 0;
+    static uint64_t tv_base = 0;
 
-    if(tv_base == 0)
-    {
-        tv_base = 1;
-        prev = 0;
-        InitializeCriticalSection(&cs);
-    }
-
-    EnterCriticalSection(&cs);
-    tv_msec = GetTickCount();
-    if(tv_msec < prev)
+    zzuf_mutex_lock(&mutex);
+    unsigned long int tv_msec = GetTickCount();
+    if (tv_msec < prev)
         tv_base += 0x100000000LL; /* We wrapped */
     prev = tv_msec;
-    LeaveCriticalSection(&cs);
+    zzuf_mutex_unlock(&mutex);
 
     return (tv_base + tv_msec) * 1000;
 #endif
